@@ -24,7 +24,7 @@ def posts():
 posts.add_command(upload.command)
 posts.add_command(download.command)
 posts.add_command(new.command)
-posts.add_command(new.og_image_command)
+posts.add_command(new.update_banner_command)
 
 
 if __name__ == "__main__":
